@@ -46,3 +46,17 @@ def wall_clock(output):
     finally:
         end = time()
         output[0] = end - start
+
+def default_if_none(x, d):
+    """
+    Returns L{x} if it's not None, otherwise returns L{d}.
+    """
+    if x is None: return d
+    else: return x
+
+def seq(f, g):
+    """
+    Evaluate 0-ary functions L{f} then L{g}, returning L{g()}.
+    """
+    f()
+    return g()
